# dik-dik
[![Release](https://github.com/mbovo/dikdik/actions/workflows/release.yml/badge.svg)](https://github.com/mbovo/dikdik/actions/workflows/release.yml)
![dikdik](https://a-z-animals.com/media/2021/09/Dik-dik-header.jpg)

Is a collection of functions and classes useful when writing python code.

